==> owncloud_7.0.4+dfsg.orig.tar.bz2: owncloud/settings/l10n/uk.php <==
<?php
$TRANSLATIONS = array(
"Email sent" => "Ел. пошта надіслана",
"Encryption" => "Шифрування",
"Unable to load list from App Store" => "Не вдалося завантажити список з App Store",
"Authentication error" => "Помилка автентифікації",
"Group already exists" => "Група вже існує",
"Unable to add group" => "Не вдалося додати групу",
"Email saved" => "Адресу збережено",
"Invalid email" => "Невірна адреса",
"Unable to delete group" => "Не вдалося видалити групу",
"Unable to delete user" => "Не вдалося видалити користувача",
"Language changed" => "Мова змінена",
"Invalid request" => "Некоректний запит",
"Admins can't remove themself from the admin group" => "Адміністратор не може видалити себе з групи адмінів",
"Unable to add user to group %s" => "Не вдалося додати користувача у групу %s",
"Unable to remove user from group %s" => "Не вдалося видалити користувача із групи %s",
"Couldn't update app." => "Не вдалося оновити програму. ",
"User Documentation" => "Документація Користувача",
"Update to {appversion}" => "Оновити до {appversion}",
"Disable" => "Вимкнути",
"Enable" => "Включити",
"Please wait...." => "Зачекайте, будь ласка...",
"Updating...." => "Оновлюється...",
"Error while updating app" => "Помилка при оновленні програми",
"Error" => "Помилка",
"Update" => "Оновити",
"Updated" => "Оновлено",
"Very weak password" => "Дуже слабкий пароль",
"Weak password" => "Слабкий пароль",
"Good password" => "Добрий пароль",
"Strong password" => "Надійний пароль",
"undo" => "відмінити",
"Groups" => "Групи",
"Group Admin" => "Адміністратор групи",
"Delete" => "Видалити",
"never" => "ніколи",
"add group" => "додати групу",
"A valid username must be provided" => "Потрібно задати вірне ім'я користувача",
"Error creating user" => "Помилка при створенні користувача",
"A valid password must be provided" => "Потрібно задати вірний пароль",
"__language_name__" => "__language_name__",
"None" => "Жоден",
"Login" => "Логін",
"Security Warning" => "Попередження про небезпеку",
"Setup Warning" => "Попередження при Налаштуванні",
"Your web server is not yet properly setup to allow files synchronization because the WebDAV interface seems to be broken." => "Ваш Web-сервер ще не налаштований належним чином для того, щоб дозволити синхронізацію файлів, через те що інтерфейс WebDAV, здається, зламаний.",
"Module 'fileinfo' missing" => "Модуль 'fileinfo' відсутній",
"The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." => "PHP модуль 'fileinfo' відсутній. Ми наполегливо рекомендуємо увімкнути цей модуль, щоб отримати кращі результати при виявленні MIME-типів.",
"Locale not working" => "Локалізація не працює",
"Internet connection not working" => "Інтернет-з'єднання не працює",
"Cron" => "Cron",
"Execute one task with each page loaded" => "Виконати одне завдання для кожної завантаженої сторінки ",
"Sharing" => "Спільний доступ",
"Allow apps to use the Share API" => "Дозволити програмам використовувати API спільного доступу",
"Allow resharing" => "Дозволити перевідкривати спільний доступ",
"Security" => "Безпека",
"Enforce HTTPS" => "Примусове застосування HTTPS",
"Server address" => "Адреса сервера",
"Port" => "Порт",
"Credentials" => "Облікові дані",
"Log" => "Протокол",
"Log level" => "Рівень протоколювання",
"More" => "Більше",
"Less" => "Менше",
"Version" => "Версія",
"Developed by the <a href=\"http://ownCloud.org/contact\" target=\"_blank\">ownCloud community</a>, the <a href=\"https://github.com/owncloud\" target=\"_blank\">source code</a> is licensed under the <a href=\"http://www.gnu.org/licenses/agpl-3.0.html\" target=\"_blank\"><abbr title=\"Affero General Public License\">AGPL</abbr></a>." => "Розроблено <a href=\"http://ownCloud.org/contact\" target=\"_blank\">ownCloud громадою</a>, <a href=\"https://github.com/owncloud\" target=\"_blank\">вихідний код</a> має ліцензію <a href=\"http://www.gnu.org/licenses/agpl-3.0.html\" target=\"_blank\"><abbr title=\"Affero General Public License\">AGPL</abbr></a>.",
"Add your App" => "Додати свою програму",
"More Apps" => "Більше програм",
"Select an App" => "Вибрати додаток",
"See application page at apps.owncloud.com" => "Перегляньте сторінку програм на apps.owncloud.com",
"<span class=\"licence\"></span>-licensed by <span class=\"author\"></span>" => "<span class=\"licence\"></span>-licensed by <span class=\"author\"></span>",
"All" => "Всі",
"Administrator Documentation" => "Документація Адміністратора",
"Online Documentation" => "Он-Лайн Документація",
"Forum" => "Форум",
"Bugtracker" => "БагТрекер",
"Commercial Support" => "Комерційна підтримка",
"Get the apps to sync your files" => "Отримати додатки для синхронізації ваших файлів",
"Show First Run Wizard again" => "Показувати Майстер Налаштувань знову",
"You have used <strong>%s</strong> of the available <strong>%s</strong>" => "Ви використали <strong>%s</strong> із доступних <strong>%s</strong>",
"Password" => "Пароль",
"Your password was changed" => "Ваш пароль змінено",
"Unable to change your password" => "Не вдалося змінити Ваш пароль",
"Current password" => "Поточний пароль",
"New password" => "Новий пароль",
"Change password" => "Змінити пароль",
"Email" => "Ел.пошта",
"Your email address" => "Ваша адреса електронної пошти",
"Cancel" => "Відмінити",
"Language" => "Мова",
"Help translate" => "Допомогти з перекладом",
"Login Name" => "Ім'я Логіну",
"Create" => "Створити",
"Default Quota" => "Квота за замовчуванням",
"Unlimited" => "Необмежено",
"Other" => "Інше",
"Username" => "Ім'я користувача",
"Quota" => "Квота",
"set new password" => "встановити новий пароль",
"Default" => "За замовчуванням"
);
$PLURAL_FORMS = "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);";

==> owncloud_7.0.13~dfsg.orig.tar.bz2: owncloud/settings/l10n/uk.php <==
<?php
$TRANSLATIONS = array(
"Email sent" => "Ел. пошта надіслана",
"Encryption" => "Шифрування",
"Unable to load list from App Store" => "Не вдалося завантажити список з App Store",
"Authentication error" => "Помилка автентифікації",
"Group already exists" => "Група вже існує",
"Unable to add group" => "Не вдалося додати групу",
"Email saved" => "Адресу збережено",
"Invalid email" => "Невірна адреса",
"Unable to delete group" => "Не вдалося видалити групу",
"Unable to delete user" => "Не вдалося видалити користувача",
"Language changed" => "Мова змінена",
"Invalid request" => "Некоректний запит",
"Admins can't remove themself from the admin group" => "Адміністратор не може видалити себе з групи адмінів",
"Unable to add user to group %s" => "Не вдалося додати користувача у групу %s",
"Unable to remove user from group %s" => "Не вдалося видалити користувача із групи %s",
"Couldn't update app." => "Не вдалося оновити програму. ",
"User Documentation" => "Документація Користувача",
"Update to {appversion}" => "Оновити до {appversion}",
"Disable" => "Вимкнути",
"Enable" => "Включити",
"Please wait...." => "Зачекайте, будь ласка...",
"Updating...." => "Оновлюється...",
"Error while updating app" => "Помилка при оновленні програми",
"Error" => "Помилка",
"Update" => "Оновити",
"Updated" => "Оновлено",
"Very weak password" => "Дуже слабкий пароль",
"Weak password" => "Слабкий пароль",
"Good password" => "Добрий пароль",
"Strong password" => "Надійний пароль",
"undo" => "відмінити",
"Groups" => "Групи",
"Group Admin" => "Адміністратор групи",
"Delete" => "Видалити",
"never" => "ніколи",
"add group" => "додати групу",
"A valid username must be provided" => "Потрібно задати вірне ім'я користувача",
"Error creating user" => "Помилка при створенні користувача",
"A valid password must be provided" => "Потрібно задати вірний пароль",
"__language_name__" => "__language_name__",
"None" => "Жоден",
"Login" => "Логін",
"Security Warning" => "Попередження про небезпеку",
"Setup Warning" => "Попередження при Налаштуванні",
"Your web server is not yet properly setup to allow files synchronization because the WebDAV interface seems to be broken." => "Ваш Web-сервер ще не налаштований належним чином для того, щоб дозволити синхронізацію файлів, через те що інтерфейс WebDAV, здається, зламаний.",
"Module 'fileinfo' missing" => "Модуль 'fileinfo' відсутній",
"The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." => "PHP модуль 'fileinfo' відсутній. Ми наполегливо рекомендуємо увімкнути цей модуль, щоб отримати кращі результати при виявленні MIME-типів.",
"Locale not working" => "Локалізація не працює",
"Internet connection not working" => "Інтернет-з'єднання не працює",
"Cron" => "Cron",
"Execute one task with each page loaded" => "Виконати одне завдання для кожної завантаженої сторінки ",
"Sharing" => "Спільний доступ",
"Allow apps to use the Share API" => "Дозволити програмам використовувати API спільного доступу",
"Allow resharing" => "Дозволити перевідкривати спільний доступ",
"Security" => "Безпека",
"Enforce HTTPS" => "Примусове застосування HTTPS",
"Server address" => "Адреса сервера",
"Port" => "Порт",
"Credentials" => "Облікові дані",
"Log" => "Протокол",
"Log level" => "Рівень протоколювання",
"More" => "Більше",
"Less" => "Менше",
"Version" => "Версія",
"Developed by the <a href=\"http://ownCloud.org/contact\" target=\"_blank\">ownCloud community</a>, the <a href=\"https://github.com/owncloud\" target=\"_blank\">source code</a> is licensed under the <a href=\"http://www.gnu.org/licenses/agpl-3.0.html\" target=\"_blank\"><abbr title=\"Affero General Public License\">AGPL</abbr></a>." => "Розроблено <a href=\"http://ownCloud.org/contact\" target=\"_blank\">ownCloud громадою</a>, <a href=\"https://github.com/owncloud\" target=\"_blank\">вихідний код</a> має ліцензію <a href=\"http://www.gnu.org/licenses/agpl-3.0.html\" target=\"_blank\"><abbr title=\"Affero General Public License\">AGPL</abbr></a>.",
"Add your App" => "Додати свою програму",
"More Apps" => "Більше програм",
"Select an App" => "Вибрати додаток",
"See application page at apps.owncloud.com" => "Перегляньте сторінку програм на apps.owncloud.com",
"<span class=\"licence\"></span>-licensed by <span class=\"author\"></span>" => "<span class=\"licence\"></span>-licensed by <span class=\"author\"></span>",
"All" => "Всі",
"Administrator Documentation" => "Документація Адміністратора",
"Online Documentation" => "Он-Лайн Документація",
"Forum" => "Форум",
"Bugtracker" => "БагТрекер",
"Commercial Support" => "Комерційна підтримка",
"Get the apps to sync your files" => "Отримати додатки для синхронізації ваших файлів",
"Show First Run Wizard again" => "Показувати Майстер Налаштувань знову",
"You have used <strong>%s</strong> of the available <strong>%s</strong>" => "Ви використали <strong>%s</strong> із доступних <strong>%s</strong>",
"Password" => "Пароль",
"Your password was changed" => "Ваш пароль змінено",
"Unable to change your password" => "Не вдалося змінити Ваш пароль",
"Current password" => "Поточний пароль",
"New password" => "Новий пароль",
"Change password" => "Змінити пароль",
"Email" => "Ел.пошта",
"Your email address" => "Ваша адреса електронної пошти",
"Cancel" => "Відмінити",
"Language" => "Мова",
"Help translate" => "Допомогти з перекладом",
"Login Name" => "Ім'я Логіну",
"Create" => "Створити",
"Default Quota" => "Квота за замовчуванням",
"Unlimited" => "Необмежено",
"Other" => "Інше",
"Username" => "Ім'я користувача",
"Quota" => "Квота",
"set new password" => "встановити новий пароль",
"Default" => "За замовчуванням",
"Connectivity Checks" => "Перевірка З'єднання",
"No problems found" => "Проблем не виявленно",
);
$PLURAL_FORMS = "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);";
